@@ -31,7 +31,6 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <pango/pango.h>
-#include <gtk/gtk.h>
 #include <eel/eel-vfs-extensions.h>
 
 #include "nautilus-file.h"
@@ -70,24 +69,6 @@ G_DEFINE_TYPE (NautilusFileConflictDialog,
 	(G_TYPE_INSTANCE_GET_PRIVATE ((object), NAUTILUS_TYPE_FILE_CONFLICT_DIALOG, \
 				      NautilusFileConflictDialogDetails))
 
-static const gchar *
-get_str_for_mtimes (NautilusFile *src,
-		    NautilusFile *dest)
-{
-	time_t src_mtime, dest_mtime;
-
-	src_mtime = nautilus_file_get_mtime (src);
-	dest_mtime = nautilus_file_get_mtime (dest);
-
-	if (src_mtime > dest_mtime)
-		return _("An older");
-
-	if (src_mtime < dest_mtime)
-		return _("A newer");
-
-	return _("Another");
-}
-
 static void
 file_icons_changed (NautilusFile *file,
 		    NautilusFileConflictDialog *fcd)
@@ -117,20 +98,19 @@ file_list_ready_cb (GList *files,
 {
 	NautilusFileConflictDialog *fcd = user_data;
 	NautilusFile *src, *dest, *dest_dir;
-	GtkDialog *dialog;
+	time_t src_mtime, dest_mtime;
 	gboolean source_is_dir,	dest_is_dir, should_show_type;
 	NautilusFileConflictDialogDetails *details;
-	char *primary_text, *secondary_text;
-	char *src_name, *dest_name, *dest_dir_name, *edit_name;
+	char *primary_text, *message, *secondary_text;
+	const gchar *message_extra;
+	char *dest_name, *dest_dir_name, *edit_name;
 	char *label_text;
 	char *size, *date, *type = NULL;
-	const gchar *time_str;
 	GdkPixbuf *pixbuf;
 	GtkWidget *label;
 	GString *str;
-	PangoFontDescription *desc;
+	PangoAttrList *attr_list;
 
-	dialog = GTK_DIALOG (fcd);
 	details = fcd->details;
 
 	details->handle = NULL;
@@ -139,7 +119,9 @@ file_list_ready_cb (GList *files,
 	dest = g_list_nth_data (files, 1);
 	src = g_list_nth_data (files, 2);
 
-	src_name = nautilus_file_get_display_name (src);
+	src_mtime = nautilus_file_get_mtime (src);
+	dest_mtime = nautilus_file_get_mtime (dest);
+
 	dest_name = nautilus_file_get_display_name (dest);
 	dest_dir_name = nautilus_file_get_display_name (dest_dir);
 
@@ -152,7 +134,6 @@ file_list_ready_cb (GList *files,
 	g_free (type);
 	type = NULL;
 
-	time_str = get_str_for_mtimes (src, dest);
 	/* Set up the right labels */
 	if (dest_is_dir) {
 		if (source_is_dir) {
@@ -160,57 +141,75 @@ file_list_ready_cb (GList *files,
 				(_("Merge folder \"%s\"?"),
 				 dest_name);
 
-			/* Translators: the first string in this printf
-			 * is the "An older/A newer/Another" string defined some lines before.
-			 */
-			secondary_text = g_strdup_printf (
-				_("%s folder with the same name already exists in \"%s\".\n"
-				  "Merging will ask for confirmation before "
-				  "replacing any files in the folder that "
-				  "conflict with the files being copied."),
-				time_str,
-				dest_dir_name);
+			message_extra = 
+				_("Merging will ask for confirmation before replacing any files in "
+				  "the folder that conflict with the files being copied.");
+
+			if (src_mtime > dest_mtime) {
+				message = g_strdup_printf (
+					_("An older folder with the same name already exists in \"%s\"."),
+					dest_dir_name);
+			} else if (src_mtime < dest_mtime) {
+				message = g_strdup_printf (
+					_("A newer folder with the same name already exists in \"%s\"."),
+					dest_dir_name);
+			} else {
+				message = g_strdup_printf (
+					_("Another folder with the same name already exists in \"%s\"."),
+					dest_dir_name);
+			}
 		} else {
+			message_extra =
+				_("Replacing it will remove all files in the folder.");
 			primary_text = g_strdup_printf
 				(_("Replace folder \"%s\"?"), dest_name);
-			secondary_text = g_strdup_printf
-				(_("A folder with the same name already exists in \"%s\".\n"
-				   "Replacing it will remove all files in the folder."),
+			message = g_strdup_printf
+				(_("A folder with the same name already exists in \"%s\"."),
 				 dest_dir_name);
 		}
 	} else {
 		primary_text = g_strdup_printf
 			(_("Replace file \"%s\"?"), dest_name);
 
-		/* Translators: the first string in this printf
-		 * is the "An older/A newer/Another" string defined some lines before.
-		 */
-		secondary_text = g_strdup_printf (
-			_("%s file with the same name already exists in \"%s\".\n"
-			  "Replacing it will overwrite its content."),
-			time_str,
-			dest_dir_name);
+		message_extra = _("Replacing it will overwrite its content.");
+
+		if (src_mtime > dest_mtime) {
+			message = g_strdup_printf (
+				_("An older file with the same name already exists in \"%s\"."),
+				dest_dir_name);
+		} else if (src_mtime < dest_mtime) {
+			message = g_strdup_printf (
+				_("A newer file with the same name already exists in \"%s\"."),
+				dest_dir_name);
+		} else {
+			message = g_strdup_printf (
+				_("Another file with the same name already exists in \"%s\"."),
+				dest_dir_name);
+		}
 	}
 
+	secondary_text = g_strdup_printf ("%s\n%s", message, message_extra);
+	g_free (message);
+
 	label = gtk_label_new (primary_text);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD_CHAR);
-	gtk_widget_set_size_request (label, 350, -1);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (details->titles_vbox),
 			    label, FALSE, FALSE, 0);
-	gtk_widget_modify_font (label, NULL);
-	desc = pango_font_description_new ();
-	pango_font_description_set_weight (desc, PANGO_WEIGHT_BOLD);
-	pango_font_description_set_size (desc,
-		pango_font_description_get_size (gtk_widget_get_style (label)->font_desc) * PANGO_SCALE_LARGE);
-	gtk_widget_modify_font (label, desc);
-	pango_font_description_free (desc);
 	gtk_widget_show (label);
 
+	attr_list = pango_attr_list_new ();
+	pango_attr_list_insert (attr_list, pango_attr_weight_new (PANGO_WEIGHT_BOLD));
+	pango_attr_list_insert (attr_list, pango_attr_scale_new (PANGO_SCALE_LARGE));
+	g_object_set (label,
+		      "attributes", attr_list,
+		      NULL);
+
+	pango_attr_list_unref (attr_list);
+
 	label = gtk_label_new (secondary_text);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_widget_set_size_request (label, 350, -1);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (details->titles_vbox),
 			    label, FALSE, FALSE, 0);
@@ -512,7 +511,7 @@ nautilus_file_conflict_dialog_init (NautilusFileConflictDialog *fcd)
 	gtk_container_add (GTK_CONTAINER (details->expander), hbox);
 
 	widget = gtk_entry_new ();
-	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 6);
 	details->entry = widget;
 	g_signal_connect (widget, "changed",
 			  G_CALLBACK (entry_text_changed_cb), dialog);
@@ -557,9 +556,8 @@ nautilus_file_conflict_dialog_init (NautilusFileConflictDialog *fcd)
 
 	/* Setup HIG properties */
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (dialog->vbox), 14);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (dialog)), 14);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_dialog_set_has_separator (dialog, FALSE);
 
 	gtk_widget_show_all (dialog_area);
 }
