@@ -198,6 +198,7 @@ static void                 preview_audio                             (NautilusI
 static void                 update_layout_menus                       (NautilusIconView     *view);
 static NautilusFileSortType get_default_sort_order                    (NautilusFile         *file,
 								       gboolean             *reversed);
+static void                 nautilus_icon_view_clear                  (NautilusView         *view);
 
 G_DEFINE_TYPE (NautilusIconView, nautilus_icon_view, NAUTILUS_TYPE_VIEW);
 
@@ -208,6 +209,8 @@ nautilus_icon_view_destroy (GtkWidget *object)
 
 	icon_view = NAUTILUS_ICON_VIEW (object);
 
+	nautilus_icon_view_clear (NAUTILUS_VIEW (object));
+
         if (icon_view->details->react_to_icon_change_idle_id != 0) {
                 g_source_remove (icon_view->details->react_to_icon_change_idle_id);
 		icon_view->details->react_to_icon_change_idle_id = 0;
@@ -1685,6 +1688,19 @@ icon_container_activate_callback (NautilusIconContainer *container,
 				      0, TRUE);
 }
 
+static void
+icon_container_activate_previewer_callback (NautilusIconContainer *container,
+					    GList *file_list,
+					    GArray *locations,
+					    NautilusIconView *icon_view)
+{
+	g_assert (NAUTILUS_IS_ICON_VIEW (icon_view));
+	g_assert (container == get_icon_container (icon_view));
+
+	nautilus_view_preview_files (NAUTILUS_VIEW (icon_view),
+				     file_list, locations);
+}
+
 /* this is called in one of these cases:
  * - we activate with enter holding shift
  * - we activate with space holding shift
@@ -2544,6 +2560,8 @@ create_icon_container (NautilusIconView *icon_view)
 
 	icon_container = nautilus_icon_view_container_new (icon_view);
 	icon_view->details->icon_container = GTK_WIDGET (icon_container);
+	g_object_add_weak_pointer (G_OBJECT (icon_container),
+				   (gpointer *) &icon_view->details->icon_container);
 	
 	gtk_widget_set_can_focus (GTK_WIDGET (icon_container), TRUE);
 	
@@ -2553,6 +2571,8 @@ create_icon_container (NautilusIconView *icon_view)
 				 G_CALLBACK (icon_container_activate_callback), icon_view, 0);
 	g_signal_connect_object (icon_container, "activate_alternate",	
 				 G_CALLBACK (icon_container_activate_alternate_callback), icon_view, 0);
+	g_signal_connect_object (icon_container, "activate_previewer",
+				 G_CALLBACK (icon_container_activate_previewer_callback), icon_view, 0);
 	g_signal_connect_object (icon_container, "band_select_started",
 				 G_CALLBACK (band_select_started_callback), icon_view, 0);
 	g_signal_connect_object (icon_container, "band_select_ended",
